==> tomee-project-8.0.9-source-release.zip: tomee-project-8.0.9/container/openejb-jee/src/main/java/org/apache/openejb/jee/oejb2/DependencyType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.oejb2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for dependencyType complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="dependencyType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://geronimo.apache.org/xml/ns/deployment-1.2}artifactType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="import" type="{http://geronimo.apache.org/xml/ns/deployment-1.2}importType" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "dependencyType", namespace = "http://geronimo.apache.org/xml/ns/deployment-1.2", propOrder = {
    "_import"
})
public class DependencyType
    extends ArtifactType {

    @XmlElement(name = "import", namespace = "http://geronimo.apache.org/xml/ns/deployment-1.2")
    protected ImportType _import;

    /**
     * Gets the value of the import property.
     *
     * @return possible object is
     * {@link ImportType }
     */
    public ImportType getImport() {
        return _import;
    }

    /**
     * Sets the value of the import property.
     *
     * @param value allowed object is
     *              {@link ImportType }
     */
    public void setImport(final ImportType value) {
        this._import = value;
    }

}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-jee/src/main/java/org/apache/openejb/jee/oejb2/DependencyType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.oejb2;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for dependencyType complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="dependencyType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://geronimo.apache.org/xml/ns/deployment-1.2}artifactType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="import" type="{http://geronimo.apache.org/xml/ns/deployment-1.2}importType" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "dependencyType", namespace = "http://geronimo.apache.org/xml/ns/deployment-1.2", propOrder = {
    "_import"
})
public class DependencyType
    extends ArtifactType {

    @XmlElement(name = "import", namespace = "http://geronimo.apache.org/xml/ns/deployment-1.2")
    protected ImportType _import;

    /**
     * Gets the value of the import property.
     *
     * @return possible object is
     * {@link ImportType }
     */
    public ImportType getImport() {
        return _import;
    }

    /**
     * Sets the value of the import property.
     *
     * @param value allowed object is
     *              {@link ImportType }
     */
    public void setImport(final ImportType value) {
        this._import = value;
    }

}
